.. _introduction:

============
Introduction
============

TauREx (Tau Retrieval for Exoplanets) is a fully bayesian inverse atmospheric retrieval framework. 
TauREx is a very extensive retrieval framework with a wide range of functionalities. TauREx3 is the 
next-generation of the atmospheric retrieval code. It acts as both a retrieval code and as a library
that provides functionality relating to atmospheric modelling. The user is free to mix and match and 
use whatever needed.

The aim of TauREx3 is for anyone to come in an put in their own physics/models/chemistry
and then perform a retrieval on it with the minimum of effort.


